==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebPaneHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPaneHeaderElementDescriptionMetadata } from "./WebPaneHeaderElementDescriptionMetadata";
import { WebPaneHeaderConnectionEventArgsDescription } from "./WebPaneHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneHeaderConnectionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneHeaderConnectionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneHeaderConnectionEventArgsDescriptionMetadata.a == null) {
                WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneHeaderConnectionEventArgsDescriptionMetadata.c(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
            WebContentPaneDescriptionMetadata.d(a);
            WebPaneHeaderElementDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneHeaderConnectionEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Pane", "ExportedType:WebContentPane");
            a.item("Element", "ExportedType:WebPaneHeaderElement");
        }
        static d(a) {
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.b(a);
            a.ac("WebPaneHeaderConnectionEventArgs", () => new WebPaneHeaderConnectionEventArgsDescription());
            a.ab("WebPaneHeaderConnectionEventArgs", WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneHeaderConnectionEventArgsDescriptionMetadata, 'WebPaneHeaderConnectionEventArgsDescriptionMetadata');
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebPaneHeaderConnectionEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebPaneHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata } from "./WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata";
import { WebPaneHeaderConnectionEventArgsDescription } from "./WebPaneHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneHeaderConnectionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneHeaderConnectionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneHeaderConnectionEventArgsDescriptionMetadata.a == null) {
                WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneHeaderConnectionEventArgsDescriptionMetadata.c(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
            WebPaneHeaderConnectionEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneHeaderConnectionEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPaneHeaderConnectionEventArgsDetail");
        }
        static d(a) {
            WebPaneHeaderConnectionEventArgsDescriptionMetadata.b(a);
            a.ac("WebPaneHeaderConnectionEventArgs", () => new WebPaneHeaderConnectionEventArgsDescription());
            a.ab("WebPaneHeaderConnectionEventArgs", WebPaneHeaderConnectionEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneHeaderConnectionEventArgsDescriptionMetadata, 'WebPaneHeaderConnectionEventArgsDescriptionMetadata');
    WebPaneHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebPaneHeaderConnectionEventArgsDescriptionMetadata;
})();
